@@ -3,78 +3,71 @@ if [ -x usr/bin/update-desktop-database ]; then
   usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
 fi
 
-( cd usr/lib ; rm -rf libkopeteprivacy.so.1 )
-( cd usr/lib ; ln -sf libkopeteprivacy.so.1.0.0 libkopeteprivacy.so.1 )
-( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so )
-( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1 libkopeteaddaccountwizard.so )
-( cd usr/lib ; rm -rf libkopete.so.4 )
-( cd usr/lib ; ln -sf libkopete.so.4.8.0 libkopete.so.4 )
-( cd usr/lib ; rm -rf libkopete_videodevice.so )
-( cd usr/lib ; ln -sf libkopete_videodevice.so.4 libkopete_videodevice.so )
-( cd usr/lib ; rm -rf libkirc.so )
-( cd usr/lib ; ln -sf libkirc.so.1 libkirc.so )
-( cd usr/lib ; rm -rf libkgetcore.so.4 )
-( cd usr/lib ; ln -sf libkgetcore.so.4.8.0 libkgetcore.so.4 )
-( cd usr/lib ; rm -rf libkopeteidentity.so.1 )
-( cd usr/lib ; ln -sf libkopeteidentity.so.1.0.0 libkopeteidentity.so.1 )
-( cd usr/lib ; rm -rf libkopete.so )
-( cd usr/lib ; ln -sf libkopete.so.4 libkopete.so )
-( cd usr/lib ; rm -rf libkyahoo.so )
-( cd usr/lib ; ln -sf libkyahoo.so.1 libkyahoo.so )
-( cd usr/lib ; rm -rf libkopete_oscar.so )
-( cd usr/lib ; ln -sf libkopete_oscar.so.4 libkopete_oscar.so )
-( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so.1 )
-( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1.0.0 libkopeteaddaccountwizard.so.1 )
-( cd usr/lib ; rm -rf libkirc.so.1 )
-( cd usr/lib ; ln -sf libkirc.so.1.0.0 libkirc.so.1 )
-( cd usr/lib ; rm -rf libkyahoo.so.1 )
-( cd usr/lib ; ln -sf libkyahoo.so.1.0.0 libkyahoo.so.1 )
-( cd usr/lib ; rm -rf libkopetestatusmenu.so.1 )
-( cd usr/lib ; ln -sf libkopetestatusmenu.so.1.0.0 libkopetestatusmenu.so.1 )
-( cd usr/lib ; rm -rf libkrdccore.so.4 )
-( cd usr/lib ; ln -sf libkrdccore.so.4.8.0 libkrdccore.so.4 )
-( cd usr/lib ; rm -rf liboscar.so )
-( cd usr/lib ; ln -sf liboscar.so.1 liboscar.so )
-( cd usr/lib ; rm -rf libkirc_client.so )
-( cd usr/lib ; ln -sf libkirc_client.so.1 libkirc_client.so )
-( cd usr/lib ; rm -rf libkopetechatwindow_shared.so.1 )
-( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1.0.0 libkopetechatwindow_shared.so.1 )
-( cd usr/lib ; rm -rf libkopetechatwindow_shared.so )
-( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1 libkopetechatwindow_shared.so )
-( cd usr/lib ; rm -rf libkopeteprivacy.so )
-( cd usr/lib ; ln -sf libkopeteprivacy.so.1 libkopeteprivacy.so )
 ( cd usr/lib ; rm -rf libkopetestatusmenu.so )
 ( cd usr/lib ; ln -sf libkopetestatusmenu.so.1 libkopetestatusmenu.so )
-( cd usr/lib ; rm -rf libkopete_videodevice.so.4 )
-( cd usr/lib ; ln -sf libkopete_videodevice.so.4.8.0 libkopete_videodevice.so.4 )
-( cd usr/lib ; rm -rf libkopeteidentity.so )
-( cd usr/lib ; ln -sf libkopeteidentity.so.1 libkopeteidentity.so )
-( cd usr/lib ; rm -rf libkopetecontactlist.so.1 )
-( cd usr/lib ; ln -sf libkopetecontactlist.so.1.0.0 libkopetecontactlist.so.1 )
-( cd usr/lib ; rm -rf libkirc_client.so.1 )
-( cd usr/lib ; ln -sf libkirc_client.so.1.0.0 libkirc_client.so.1 )
+( cd usr/lib ; rm -rf libkopetechatwindow_shared.so )
+( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1 libkopetechatwindow_shared.so )
+( cd usr/lib ; rm -rf libkirc_client.so )
+( cd usr/lib ; ln -sf libkirc_client.so.1 libkirc_client.so )
 ( cd usr/lib ; rm -rf libkopetecontactlist.so )
 ( cd usr/lib ; ln -sf libkopetecontactlist.so.1 libkopetecontactlist.so )
-( cd usr/lib ; rm -rf liboscar.so.1 )
-( cd usr/lib ; ln -sf liboscar.so.1.0.0 liboscar.so.1 )
-( cd usr/lib ; rm -rf libkopete_oscar.so.4 )
-( cd usr/lib ; ln -sf libkopete_oscar.so.4.8.0 libkopete_oscar.so.4 )
-( cd usr/lib ; rm -rf libkgetcore.so )
-( cd usr/lib ; ln -sf libkgetcore.so.4 libkgetcore.so )
+( cd usr/lib ; rm -rf liboscar.so )
+( cd usr/lib ; ln -sf liboscar.so.1 liboscar.so )
+( cd usr/lib ; rm -rf libkopeteprivacy.so.1 )
+( cd usr/lib ; ln -sf libkopeteprivacy.so.1.0.0 libkopeteprivacy.so.1 )
 ( cd usr/lib ; rm -rf libkrdccore.so )
 ( cd usr/lib ; ln -sf libkrdccore.so.4 libkrdccore.so )
-( cd usr/doc/HTML/en/kppp ; rm -rf common )
-( cd usr/doc/HTML/en/kppp ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/doc/HTML/en/kget ; rm -rf common )
-( cd usr/doc/HTML/en/kget ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/lib ; rm -rf libkyahoo.so.1 )
+( cd usr/lib ; ln -sf libkyahoo.so.1.0.0 libkyahoo.so.1 )
+( cd usr/lib ; rm -rf libkrdccore.so.4 )
+( cd usr/lib ; ln -sf libkrdccore.so.4.10.5 libkrdccore.so.4 )
+( cd usr/lib ; rm -rf libkopeteidentity.so.1 )
+( cd usr/lib ; ln -sf libkopeteidentity.so.1.0.0 libkopeteidentity.so.1 )
+( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so )
+( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1 libkopeteaddaccountwizard.so )
+( cd usr/lib ; rm -rf libkopete_videodevice.so.4 )
+( cd usr/lib ; ln -sf libkopete_videodevice.so.4.10.5 libkopete_videodevice.so.4 )
+( cd usr/lib ; rm -rf libkgetcore.so )
+( cd usr/lib ; ln -sf libkgetcore.so.4 libkgetcore.so )
+( cd usr/lib ; rm -rf libkirc.so )
+( cd usr/lib ; ln -sf libkirc.so.1 libkirc.so )
+( cd usr/lib ; rm -rf libkirc.so.1 )
+( cd usr/lib ; ln -sf libkirc.so.1.0.0 libkirc.so.1 )
+( cd usr/lib ; rm -rf libkirc_client.so.1 )
+( cd usr/lib ; ln -sf libkirc_client.so.1.0.0 libkirc_client.so.1 )
+( cd usr/lib ; rm -rf libkopetecontactlist.so.1 )
+( cd usr/lib ; ln -sf libkopetecontactlist.so.1.0.0 libkopetecontactlist.so.1 )
+( cd usr/lib ; rm -rf libkyahoo.so )
+( cd usr/lib ; ln -sf libkyahoo.so.1 libkyahoo.so )
+( cd usr/lib ; rm -rf libkopetechatwindow_shared.so.1 )
+( cd usr/lib ; ln -sf libkopetechatwindow_shared.so.1.0.0 libkopetechatwindow_shared.so.1 )
+( cd usr/lib ; rm -rf libkopete_oscar.so.4 )
+( cd usr/lib ; ln -sf libkopete_oscar.so.4.10.5 libkopete_oscar.so.4 )
+( cd usr/lib ; rm -rf libkopeteidentity.so )
+( cd usr/lib ; ln -sf libkopeteidentity.so.1 libkopeteidentity.so )
+( cd usr/lib ; rm -rf libkgetcore.so.4 )
+( cd usr/lib ; ln -sf libkgetcore.so.4.10.5 libkgetcore.so.4 )
+( cd usr/lib ; rm -rf libkopeteprivacy.so )
+( cd usr/lib ; ln -sf libkopeteprivacy.so.1 libkopeteprivacy.so )
+( cd usr/lib ; rm -rf libkopete_videodevice.so )
+( cd usr/lib ; ln -sf libkopete_videodevice.so.4 libkopete_videodevice.so )
+( cd usr/lib ; rm -rf libkopeteaddaccountwizard.so.1 )
+( cd usr/lib ; ln -sf libkopeteaddaccountwizard.so.1.0.0 libkopeteaddaccountwizard.so.1 )
+( cd usr/lib ; rm -rf libkopete.so.4 )
+( cd usr/lib ; ln -sf libkopete.so.4.10.5 libkopete.so.4 )
+( cd usr/lib ; rm -rf liboscar.so.1 )
+( cd usr/lib ; ln -sf liboscar.so.1.0.0 liboscar.so.1 )
+( cd usr/lib ; rm -rf libkopete.so )
+( cd usr/lib ; ln -sf libkopete.so.4 libkopete.so )
+( cd usr/lib ; rm -rf libkopetestatusmenu.so.1 )
+( cd usr/lib ; ln -sf libkopetestatusmenu.so.1.0.0 libkopetestatusmenu.so.1 )
+( cd usr/lib ; rm -rf libkopete_oscar.so )
+( cd usr/lib ; ln -sf libkopete_oscar.so.4 libkopete_oscar.so )
 ( cd usr/doc/HTML/en/krfb ; rm -rf common )
 ( cd usr/doc/HTML/en/krfb ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/doc/HTML/en/krdc ; rm -rf common )
-( cd usr/doc/HTML/en/krdc ; ln -sf /usr/share/doc/HTML/en/common common )
 ( cd usr/doc/HTML/en/kopete ; rm -rf common )
 ( cd usr/doc/HTML/en/kopete ; ln -sf /usr/share/doc/HTML/en/common common )
-
-if [ -x usr/bin/update-desktop-database ]; then
-  usr/bin/update-desktop-database usr/share/applications >/dev/null 2>&1
-fi
-
+( cd usr/doc/HTML/en/kppp ; rm -rf common )
+( cd usr/doc/HTML/en/kppp ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/doc/HTML/en/krdc ; rm -rf common )
+( cd usr/doc/HTML/en/krdc ; ln -sf /usr/share/doc/HTML/en/common common )
